dim=3;d=3;
[geodir,meshdir]=fc_vfemp1.default_directories(dim);
N=15;
geofile=[geodir,filesep,'cylinderkey.geo'];


solver=@(A,b) minres(A,b,1e-6,400);


fprintf('1. Building the mesh using GMSH\n');
meshfile=gmsh.buildmesh(geofile,N,'d',d,'geodir',geodir,'meshdir',meshdir);
Th=siMesh(meshfile);
fprintf('     Mesh sizes : nq=%d, nme=%d, h=%.3e\n',Th.nq,Th.get_nme(),Th.get_h());

fprintf('2.a Setting 3D potential velocity/flow BVP\n');
d=3;dim=3;m=4;
Hop=Hoperator(dim,d,m);
Hop.set(1,2,Loperator(dim,d,[],{-1,0,0},[],[]));
Hop.set(1,3,Loperator(dim,d,[],{0,-1,0},[],[]));
Hop.set(1,4,Loperator(dim,d,[],{0,0,-1},[],[]));
Hop.set(2,1,Loperator(dim,d,[],[],{-1,0,0},[]));
Hop.set(2,2,Loperator(dim,d,[],[],[],1));
Hop.set(3,1,Loperator(dim,d,[],[],{0,-1,0},[]));
Hop.set(3,3,Loperator(dim,d,[],[],[],1));
Hop.set(4,1,Loperator(dim,d,[],[],{0,0,-1},[]));
Hop.set(4,4,Loperator(dim,d,[],[],[],1));
bvpFlow=BVP(Th,PDEelt(Hop));
bvpFlow.setDirichlet(1020,-1,1);
bvpFlow.setDirichlet(1021,1,1);
bvpFlow.setDirichlet(2020,-1,1);
bvpFlow.setDirichlet(2021,1,1);

fprintf('2.b Solving 3D potential velocity/flow BVP\n')%,'solver',solver);
W=bvpFlow.solve('split',true);
fprintf('3.a Setting 3D stationary heat BVP with potential flow\n');
af=@(x,y,z) 1+(z-1).^2;
Lop=Loperator(dim,d,{af,[],[];[],af,[];[],[],af},[],{W{2},W{3},W{4}},0.01);
bvpHeat=BVP(Th,PDEelt(Lop));
bvpHeat.setDirichlet(1020,30.);
bvpHeat.setDirichlet(2020,30.);
bvpHeat.setDirichlet(10, @(x,y,z) 10*(abs(z-1)>0.5));
fprintf('3.b Solve 3d stationnary heat P.D.E. with potential flow\n');
U=bvpHeat.solve();

fprintf('4. Graphic representations\n');
close all
options=fc_tools.graphics.DisplayFigures('nfig',8);
interpreter=@(x) fc_tools.graphics.interpreter(x);
Phi=W{1};isorange=linspace(min(Phi),max(Phi),20);
isOctave=fc_tools.comp.isOctave();

figure(1)
Th.plotmesh('d',2,'legend',true,'EdgeColor','none')
xlabel('x'),ylabel('y'),zlabel('z')
axis image
  
figure(2)
Th.plotmesh('d',2,'legend',true,'EdgeColor','none')
xlabel('x'),ylabel('y'),zlabel('z')
axis image
view(-85,-70)
  

figure(3)
colormap(jet)
Th.plot(Phi,'d',2,'FaceColor','interp','EdgeColor','none')
hold on,axis off,axis image
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
Th.plotiso(Phi,'isorange',isorange,'Color','w')
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$\Phi$'),options.title{:},options.interpreter{:})
if ~isOctave(),camzoom(1.3);end
  
figure(4)
colormap(jet)
VelocityMagnitude=sqrt(W{2}.^2+W{3}.^2+W{4}.^2);
mV=max(VelocityMagnitude);
Th.plotmesh('d',2,'labels',[10,11,31],'FaceColor',0.8*[1,1,1],'EdgeColor',0.9*[1,1,1])
hold on,axis off,axis image
Th.plotVectorField([W{2},W{3},W{4}],'colordata',U,'scale',2*Th.get_h()/mV,'freq',2)
%caxis([min(U),max(U)])
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})
axis image, axis off
if ~isOctave(),camzoom(1.3);end

figure(5)
colormap(jet)
Th.plotmesh('d',2,'labels',[10,11,31],'FaceColor',0.8*[1,1,1],'EdgeColor',0.9*[1,1,1])
hold on,axis off,axis image
Th.plotVectorField([W{2},W{3},W{4}]','colordata',U,'scale',2*Th.get_h()/mV,'freq',2)
caxis([min(U),max(U)])
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})
axis image, axis off
view(-109,26)
if ~isOctave(),camzoom(1.3);end

isorange=linspace(min(U),max(U),20);
figure(6)
colormap(jet)
Th.plot(U,'d',2,'FaceColor','interp','EdgeColor','none')
hold on,axis off,axis image
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
Th.plotiso(U,'isorange',isorange,'Color','w')
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})
if ~isOctave(),camzoom(1.3);end

figure(7)
colormap(jet)
Th.plotmesh('d',2,'labels',[10,11,31],'FaceColor',0.8*[1,1,1],'EdgeColor',0.9*[1,1,1])
hold on,axis off,axis image
Th.plotVectorField([W{2},W{3},W{4}]','colordata',U,'scale',1.3*Th.get_h()/mV,'freq',2)
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
colorbar(options.colorbar{:})
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})
if ~isOctave(),camzoom(1.3);end

figure(8)
colormap(jet)
Th.plot(U,'d',2,'labels',[10,11,31,1000,1020,1021,2000,2020,2021],'FaceColor','interp','EdgeColor','none')
hold on,axis off,axis image
Th.plotmesh('d',1,'Color','k','Linewidth',1.5)
Th.plotiso(U,'labels',[10,11,31,1000,1020,1021,2000,2020,2021],'isorange',isorange,'Color','w')
P1=fc_tools.graphics.PlaneCoefs([0 0 1],[0 0 1]);
Th.slice(U,P1,'FaceColor','interp')
Th.sliceiso(U,P1,'isorange',isorange,'Color','w')
set(get(colorbar(),'title'),'string',interpreter('$u$'),options.title{:},options.interpreter{:})
view(-35,26)
if ~isOctave(),camzoom(1.3);end