%function BVPPoisson2D_ex01()
close all
N=200;
verbose=2;

[bvp,info]=fc_vfemp1.samples.Poisson.setBVPPoisson2D_ex01(N,verbose);

if verbose>=2, fprintf('3. Solving B.V.P. problem\n');end
tstart=tic();
U=bvp.solve();
tcpu=toc(tstart);
fprintf('  -> ndof (number of degrees of freedom) = %d\n',length(U));
fprintf('  -> solved in %.3f(s)\n',tcpu);

if verbose>=2 
  fprintf('4. Errors computation\n');
  %fprintf('  -> exact solution : %s\n',func2str(info.solex));
end
Th=bvp.Th;
Uex=Th.eval(info.solex);
E=U-Uex;
ErrLinf=norm(E,Inf)/(norm(U,Inf)+1);
[ErrH1,Mass,Stiff]=FEM.NormH1(Th,E);
ErrH1=ErrH1/(FEM.NormH1(Th,U,'Mass',Mass,'Stiff',Stiff)+1);
ErrL2=FEM.NormL2(Th,E,'Mass',Mass)/(FEM.NormL2(Th,U,'Mass',Mass)+1);
if verbose>=2 
  fprintf('  -> rel. Inf. error : %.4e\n',ErrLinf);
  fprintf('  -> rel. L2 error   : %.4e\n',ErrL2);
  fprintf('  -> rel. H1 error   : %.4e\n',ErrH1);
end

if verbose>=2, fprintf('5. Graphic representations\n');end
figure(1)
Th.plotmesh('legend',false,'color',[0.8,0.8,0.8])
hold on
Th.plotmesh('d',1,'LineWidth',2)
axis off,axis image

figure(2)
Th.plot(U)
axis off,axis image
colorbar
shading interp
title('Poisson2d[ex01], P1-FEM solution')

figure(3)
Th.plot(abs(U-Uex))
axis off,axis image
colorbar
shading interp
title('Poisson2d[ex01], P1-FEM error')


